@@ -60,7 +60,7 @@ class marcxmlhandler(sax.ContentHandler):
                 self._record.append(self._chardata_dest)
                 self._getcontent = True
             elif local == u'datafield':
-                self._record.append([DATAFIELD, attributes[None, u'tag'].strip(), dict((k, v.strip()) for (k, v) in attributes.items()), []])
+                self._record.append([DATAFIELD, attributes[None, u'tag'].strip(), dict((k[1], v.strip()) for (k, v) in attributes.items()), []])
             elif local == u'subfield':
                 self._chardata_dest = [attributes[None, u'code'].strip(), u'']
                 self._record[-1][3].append(self._chardata_dest)
@@ -94,7 +94,7 @@ class marcxmlhandler(sax.ContentHandler):
 
 #PYTHONASYNCIODEBUG = 1
 
-def bfconvert(inputs, base=None, out=None, limit=None, rdfttl=None, config=None, verbose=False, logger=logging):
+def bfconvert(inputs, base=None, out=None, limit=None, rdfttl=None, rdfxml=None, config=None, verbose=False, logger=logging):
     '''
     inputs - List of MARC/XML files to be parsed and converted to BIBFRAME RDF (Note: want to allow singular input strings)
     out - file where raw Versa JSON dump output should be written (default: write to stdout)
@@ -132,7 +132,7 @@ def bfconvert(inputs, base=None, out=None, limit=None, rdfttl=None, config=None,
     #extant_resources = set()
     def postprocess(rec):
         #No need to bother with Versa -> RDF translation if we were not asked to generate Turtle
-        if rdfttl is not None: rdf.process(m, g, to_ignore=extant_resources, logger=logger)
+        if any((rdfttl, rdfxml)): rdf.process(m, g, to_ignore=extant_resources, logger=logger)
         m.create_space()
 
     #Set up event loop
@@ -166,12 +166,21 @@ def bfconvert(inputs, base=None, out=None, limit=None, rdfttl=None, config=None,
         def wrap_task():
             parser.parse(inf)
             yield
-        asyncio.Task(wrap_task())
+        task = asyncio.Task(wrap_task())
         #parse_marcxml(inf, sink)
-        loop.run_forever()
+        try:
+            loop.run_until_complete(task)
+        except Exception as ex:
+            raise ex
+        finally:
+            loop.close()
 
     if rdfttl is not None:
         logger.debug('Converting to RDF.')
         rdfttl.write(g.serialize(format="turtle"))
+
+    if rdfxml is not None:
+        logger.debug('Converting to RDF.')
+        rdfxml.write(g.serialize(format="pretty-xml"))
     return
 
